Name:		hail
Version:	0.8
Release:	0.5.gf9c5b967%{?dist}
Summary:	Project Hail core cloud services

Group:		System Environment/Libraries
License:	GPLv2
URL:		http://hail.wiki.kernel.org/

# pulled from upstream git, commit f9c5b967cb409cb3e38870b21292374ccea3ee6e
# to recreate tarball, check out commit, then run "make dist"
Source0:	hail-%{version}git.tar.gz

# cld, chunkd init.d and sysconfig data.  copied from pkg/* in upstream git,
# commit 554f1338e29342ba6dcfa0bce648d304afc2c1e1
Source2:	cld.service
Source3:	cld.sysconf
Source4:	chunkd.service
Source5:	chunkd.sysconf

BuildRequires:	db4-devel glib2-devel doxygen openssl-devel
BuildRequires:	texlive-latex fuse-devel libcurl-devel
BuildRequires:	libxml2-devel procps tokyocabinet-devel
BuildRequires:	systemd-units

%description
Core libraries and document associated with cloud computing related
Project Hail.

%package -n cld
Summary: Coarse locking service for %{name}
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires(post): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

%description -n cld
Coarse locking daemon for cloud computing.  This software provides
a cache-coherent, highly-available distributed file system for small
files.

CLD's primary uses include consensus service (election of a master,
with fail-over, also known as lock service), reliable name space,
and reliable small file storage.

%package -n chunkd
Summary: Single-node data storage service for %{name}
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires(post): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

%description -n chunkd
Single-node data storage daemon for cloud computing.

This TCP network service is a very simple PUT/GET/DELETE data storage
service.  It is intended to be used as a low-level piece of large-scale
distributed data storage infrastructure.  The service provides
operations on stored data ("objects").

%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig openssl-devel glib2-devel
Conflicts: cld-devel chunkd-devel

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n hail-0.8git

%build
%configure --disable-static
make %{?_smp_mflags}
rm -rf gendoc && mkdir gendoc && doxygen
( cd gendoc/latex && make )

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

mkdir -p %{buildroot}%{_unitdir}
install -m 755 %{SOURCE2} %{buildroot}%{_unitdir}/

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/cld

install -m 755 %{SOURCE4} %{buildroot}%{_unitdir}/

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/chunkd

mkdir -p %{buildroot}%{_libdir}/cld/lib

find %{buildroot} -name '*.la' -exec rm -f {} ';'

%check
make -s check

%post -p /sbin/ldconfig

%post -n cld
if [ $1 -eq 1 ] ; then 
    # Initial installation 
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%preun -n cld
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable cld.service > /dev/null 2>&1 || :
    /bin/systemctl stop cld.service > /dev/null 2>&1 || :
fi

%postun -n cld
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart cld.service >/dev/null 2>&1 || :
fi

%triggerun -n cld -- cld < 0.8-0.4.gf9c5b967
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply cld
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save cld >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del cld >/dev/null 2>&1 || :
/bin/systemctl try-restart cld.service >/dev/null 2>&1 || :

%post -n chunkd
if [ $1 -eq 1 ] ; then
    # Initial installation
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%preun -n chunkd
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable chunkd.service > /dev/null 2>&1 || :
    /bin/systemctl stop chunkd.service > /dev/null 2>&1 || :
fi

%postun	-n chunkd
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart chunkd.service >/dev/null 2>&1 || :
fi

%triggerun -n chunkd -- chunkd < 0.8-0.4.gf9c5b967
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply chunkd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save chunkd >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del chunkd >/dev/null 2>&1 || :
/bin/systemctl try-restart chunkd.service >/dev/null 2>&1 || :

%postun -p /sbin/ldconfig

%files
%doc AUTHORS COPYING LICENSE README NEWS doc/contributions.txt
%{_libdir}/*.so.*

%files -n cld
%{_sbindir}/cld
%{_bindir}/cldcli
%{_mandir}/man8/cldcli.8*
%{_mandir}/man8/cld.8*
%{_libdir}/cld
%{_unitdir}/cld.service
%config(noreplace)	%{_sysconfdir}/sysconfig/cld

%files -n chunkd
%doc doc/api.txt doc/cfgfile.txt doc/chcli.cfg doc/chcli.txt
%doc doc/concept.txt doc/logging.txt
%{_sbindir}/chunkd
%{_bindir}/chcli
%{_mandir}/man8/chcli.8*
%{_mandir}/man8/chunkd.8*
%{_unitdir}/chunkd.service
%config(noreplace)	%{_sysconfdir}/sysconfig/chunkd

%files devel
%doc gendoc/html gendoc/latex/refman.pdf
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*

%changelog
* Fri Sep 09 2011 Tom Callaway <spot@fedoraproject.org> - 0.8-0.5.gf9c5b967
- add missing systemd scriptlets

* Thu Sep 08 2011 Tom Callaway <spot@fedoraproject.org> - 0.8-0.4.gf9c5b967
- convert to systemd

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-0.3.gf9c5b967
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jul 14 2010 Jeff Garzik <jgarzik@redhat.com> - 0.8-0.2.gf9c5b967
- Update to upstream commit f9c5b967cb409cb3e38870b21292374ccea3ee6e

* Tue Jul 13 2010 Jeff Garzik <jgarzik@redhat.com> - 0.8-0.1.gee257f18
- Update to upstream commit ee257f18f601922df84687736c6bd1ac76b16580

* Fri Jul  2 2010 Jeff Garzik <jgarzik@redhat.com> - 0.7-1
- Initial release.

